@extends('frontEnd.layouts.master')
@section('title', $details->name)
@push('seo')
    <meta name="app-url" content="{{ route('product', $details->slug) }}" />
    <meta name="robots" content="index, follow" />
    <meta name="description" content="{{ $details->meta_description }}" />
    <meta name="keywords" content="{{ $details->slug }}" />

    <!-- Twitter Card data -->
    <meta name="twitter:card" content="product" />
    <meta name="twitter:site" content="{{ $details->name }}" />
    <meta name="twitter:title" content="{{ $details->name }}" />
    <meta name="twitter:description" content="{{ $details->meta_description }}" />
    <meta name="twitter:creator" content="kadobd.com" />
    <meta property="og:url" content="{{ route('product', $details->slug) }}" />
    <meta name="twitter:image" content="{{ asset($details->image->image) }}" />

    <!-- Open Graph data -->
    <meta property="og:title" content="{{ $details->name }}" />
    <meta property="og:type" content="product" />
    <meta property="og:url" content="{{ route('product', $details->slug) }}" />
    <meta property="og:image" content="{{ asset($details->image->image) }}" />
    <meta property="og:description" content="{{ $details->meta_description }}" />
    <meta property="og:site_name" content="{{ $details->name }}" />
@endpush

@push('css')
    <link rel="stylesheet" href="{{ asset('public/frontEnd/css/zoomsl.css') }}">
@endpush

@section('content')
    <div class="homeproduct main-details-page">
        <div class="container">
            <div class="row">
                <div class="col-sm-12">
                    <div class="product-section">
                        <div class="container">
                            <div class="row">
                                <div class="col-sm-5 position-relative">
                                    @if ($details->old_price)
                                        <div class="discount">
                                            <p> @php $discount=(((($details->old_price)-($details->new_price))*100) / ($details->old_price)) @endphp {{ number_format($discount, 0) }}% OFF</p>
                                        </div>
                                    @endif
                                    <div class="details_slider owl-carousel">
                                        @foreach ($details->images as $value)
                                            <div class="dimage_item">
                                                <img src="{{ asset($value->image) }}" class="block__pic" />
                                            </div>
                                        @endforeach
                                    </div>
                                    <div
                                        class="indicator_thumb @if ($details->images->count() > 4) thumb_slider owl-carousel @endif">
                                        @foreach ($details->images as $key => $image)
                                            <div class="indicator-item" data-id="{{ $key }}">
                                                <img src="{{ asset($image->image) }}" />
                                            </div>
                                        @endforeach
                                    </div>
                                </div>
                                <div class="col-sm-7">
                                    <div class="details_right">
                                        <div class="breadcrumb">
                                            <ul>
                                                <li><a href="{{ url('/') }}">Home</a></li>
                                                <li><span>/</span></li>
                                                <li><a
                                                        href="{{ url('/category/' . $details->category->slug) }}">{{ $details->category->name }}</a>
                                                </li>
                                                @if ($details->subcategory)
                                                    <li><span>/</span></li>
                                                    <li><a
                                                            href="#">{{ $details->subcategory ? $details->subcategory->subcategoryName : '' }}</a>
                                                    </li>
                                                    @endif @if ($details->childcategory)
                                                        <li><span>/</span></li>
                                                        <li><a
                                                                href="#">{{ $details->childcategory->childcategoryName }}</a>
                                                        </li>
                                                    @endif
                                            </ul>
                                        </div>

                                        <div class="product">
                                            <div class="product-cart">
                                                <p class="name">{{ $details->name }}</p>
                                                <p class="details-price">
                                                    @if ($details->old_price)
                                                        <del>৳{{ $details->old_price }}</del>
                                                    @endif ৳{{ $details->new_price }}
                                                </p>
                                                <div class="details-ratting-wrapper">
                                                    @php
                                                        $averageRating = $reviews->avg('ratting');
                                                        $filledStars = floor($averageRating);
                                                        $emptyStars = 5 - $filledStars;
                                                    @endphp

                                                    @if ($averageRating >= 0 && $averageRating <= 5)
                                                        @for ($i = 1; $i <= $filledStars; $i++)
                                                            <i class="fas fa-star"></i>
                                                        @endfor

                                                        @if ($averageRating == $filledStars)
                                                            {{-- If averageRating is an integer, don't display half star --}}
                                                        @else
                                                            <i class="far fa-star-half-alt"></i>
                                                        @endif

                                                        @for ($i = 1; $i <= $emptyStars; $i++)
                                                            <i class="far fa-star"></i>
                                                        @endfor

                                                        <span>{{ number_format($averageRating, 2) }}/5</span>
                                                    @else
                                                        <span>Invalid rating range</span>
                                                    @endif
                                                    <a class="all-reviews-button" href="#writeReview">See Reviews</a>
                                                </div>
                                                <div class="product-code">
                                                    <p><span>SKU : </span>{{ $details->product_code }}</p>
                                                </div>
                                                <form action="{{ route('cart.store') }}" method="POST" name="formName">
                                                    @csrf
                                                    <input type="hidden" name="id" value="{{ $details->id }}" />
                                                    @if ($productcolors->count() > 0)
                                                        <div class="pro-color" style="width: 100%;">
                                                            <div class="color_inner">
                                                                <p>Color -</p>
                                                                <div class="size-container">
                                                                    <div class="selector">
                                                                        @foreach ($productcolors as $key => $procolor)
                                                                        @php
                                                                            $color = \App\Models\Color::where('colorName', $procolor->color)->first();
                                                                        @endphp
                                                                            <div class="selector-item">
                                                                                <input type="radio"
                                                                                    id="fc-option{{ $key }}"
                                                                                    value="{{ $procolor->color }}"
                                                                                    name="product_color"
                                                                                    class="selector-item_radio emptyalert stock_check stock_color"
                                                                                    data-color="{{ $procolor->color }}"
                                                                                    @if ($productcolors->count() == 1)
                                                                                    checked
                                                                                    @endif
                                                                                    required />
                                                                                <label for="fc-option{{ $key }}"
                                                                                    style="background-color: {{ $color->color }}"
                                                                                    data-bs-toggle="tooltip" data-bs-placement="top" title="{{ $procolor->color }}"
                                                                                    class="selector-item_label">
                                                                                    <span>
                                                                                        <img src="{{ asset('public/frontEnd/images') }}/check-icon.svg"
                                                                                            alt="Checked Icon" />
                                                                                    </span>
                                                                                </label>
                                                                            </div>
                                                                        @endforeach
                                                                    </div>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    @endif
                                                    @if ($productsizes->count() > 0)
                                                        <div class="pro-size" style="width: 100%;">
                                                            <div class="size_inner">
                                                                <p>Size - <span class="attibute-name"></span></p>
                                                                <div class="size-container">
                                                                    <div class="selector">
                                                                        @foreach ($productsizes as $key => $prosize)
                                                                            <div class="selector-item">
                                                                                <input type="radio"
                                                                                    id="f-option{{ $key }}"
                                                                                    value="{{ $prosize->size }}"
                                                                                    name="product_size"
                                                                                    class="selector-item_radio emptyalert stock_check stock_size"
                                                                                    data-size="{{ $prosize->size }}"
                                                                                    required />
                                                                                <label for="f-option{{ $key }}"
                                                                                    class="selector-item_label">{{ $prosize->size }}</label>
                                                                            </div>
                                                                        @endforeach
                                                                    </div>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    @endif
                                                    <div class="stock_summary">
                                                        @if ($details->type == 0)
                                                            <p data-stock="{{ $details->quantity }}"><strong>Stock:
                                                                    {{ $details->quantity }}</p>
                                                        @endif
                                                    </div>
                                                    @if ($details->pro_unit)
                                                        <div class="pro_unig">
                                                            <label>Unit: {{ $details->pro_unit }}</label>
                                                            <input type="hidden" name="pro_unit"
                                                                value="{{ $details->pro_unit }}" />
                                                        </div>
                                                    @endif
                                                    <div class="pro_brand">
                                                        <p>Brand :
                                                            {{ $details->brand ? $details->brand->name : 'N/A' }}
                                                        </p>
                                                    </div>
                                                    @if (($details->variables_count < 1 && $details->type == 1) || ($details->quantity < 1 && $details->type == 0))
                                                        <div class="row">
                                                            <div class="col-sm-12">
                                                                <a class="details_stock_out">stock out</a>
                                                            </div>
                                                        </div>
                                                    @else
                                                        <div class="row">
                                                            <div class="qty-cart col-sm-12">
                                                                <div class="quantity">
                                                                    <span class="minus">-</span>
                                                                    <input type="text" name="qty"
                                                                        value="1" />
                                                                    <span class="plus">+</span>
                                                                </div>
                                                            </div>
                                                            <div class="d-flex single_product col-sm-12">
                                                                <input type="submit" class="btn px-4 add_cart_btn"
                                                                    onclick="return sendSuccess();" name="add_cart"
                                                                    value="Add To Cart " />

                                                                <input type="submit"
                                                                    class="btn px-4 order_now_btn order_now_btn_m"
                                                                    onclick="return sendSuccess();" name="order_now"
                                                                    value="Order Now" />
                                                            </div>
                                                        </div>
                                                    @endif
                                                    <div class="mt-md-2 mt-2">
                                                        <h4 class="font-weight-bold">
                                                            <a class="btn btn-success w-100 call_now_btn"
                                                                href="tel: {{ $contact->hotline }}">
                                                                <i class="fa fa-phone-square"></i>
                                                                {{ $contact->hotline }}
                                                            </a>
                                                        </h4>
                                                    </div>
                                                    <div class="mt-md-2 mt-2">
                                                        <div class="del_charge_area">
                                                            <div class="alert alert-info text-xs">
                                                                <div class="flext_area">
                                                                    <i class="fa-solid fa-cubes"></i>
                                                                    <div>
                                                                        {!! $generalsetting->shipping_note !!}
                                                                    </div>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </form>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <div class="description-nav-wrapper">
        <div class="container">
            <div class="row">
                <div class="col-sm-12">
                    <div class="description-nav">
                        <ul class="desc-nav-ul">
                            <li>
                                <a href="#description" target="_self">Description</a>
                            </li>
                            <li>
                                <a href="#writeReview" target="_self">Reviews ({{ $reviews->count() }}) </a>
                            </li>
                        </ul>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <section class="pro_details_area">
        <div class="container">
            <div class="row">
                <div class="col-sm-8">
                    <div class="description tab-content details-action-box" id="description">
                        <h2>Description</h2>
                        <p>{!! $details->description !!}</p>
                    </div>
                    <div class="tab-content details-action-box" id="writeReview">
                        <div class="container">
                            <div class="row">
                                <div class="col-sm-12">
                                    <div class="section-head">
                                        <div class="title">
                                            <h2>Reviews ({{ $reviews->count() }})</h2>
                                            <p>Get specific details about this product from customers who own it.</p>
                                        </div>
                                        <div class="action">
                                            <div>
                                                <button type="button" class="details-action-btn question-btn btn-overlay"
                                                    data-bs-toggle="modal" data-bs-target="#exampleModal">
                                                    Write a review
                                                </button>
                                            </div>
                                        </div>
                                    </div>
                                    @if ($reviews->count() > 0)
                                        <div class="review_summary_inner">
                                            <h5 class="review_title">Reviews & Ratting</h5>
                                            <div class="review_box">
                                                <div class="review_counter">
                                                    <ul class="review_excellent">
                                                        <li>
                                                            @if ($total_review)
                                                                {{ number_format($total_review / $details->reviews_count, 2) }}
                                                            @else
                                                                0
                                                            @endif
                                                        </li>
                                                        <li><span><i class="far fa-star"></i> Excellent</span></li>

                                                    </ul>
                                                    <ul class="review_counter">
                                                        <li>
                                                            @php
                                                                $reviews = $details->reviews;
                                                                $averageRating = $reviews->isEmpty()
                                                                    ? 0
                                                                    : $reviews->avg('ratting');
                                                                $filledStars = floor($averageRating);
                                                                $emptyStars = 5 - $filledStars;
                                                            @endphp
                                                            @if ($averageRating >= 0 && $averageRating <= 5)
                                                                @for ($i = 1; $i <= $filledStars; $i++)
                                                                    <i class="fas fa-star"></i>
                                                                @endfor
                                                                @if (is_int($averageRating))
                                                                    @for ($i = 1; $i <= $emptyStars; $i++)
                                                                        <i class="far fa-star"></i>
                                                                    @endfor
                                                                @else
                                                                    <i class="far fa-star-half-alt"></i>
                                                                    @for ($i = 1; $i < $emptyStars; $i++)
                                                                        <i class="far fa-star"></i>
                                                                    @endfor
                                                                @endif

                                                        </li>
                                    @endif
                                    <li class="d-block">{{ $details->reviews_count }} Ratting</li>

                                    </ul>
                                </div>
                                <div class="review_counter_line">
                                    <ul>
                                        <li>5 Star</li>
                                        <li>

                                            <div class="progress">
                                                <div class="progress-bar bg-success" role="progressbar"
                                                    aria-label="5 start" style="width: 80%;" aria-valuenow="25"
                                                    aria-valuemin="0" aria-valuemax="100"></div>
                                            </div>
                                        </li>
                                        <li>({{ $five_star->count() }})</li>
                                    </ul>
                                    <!--review line-->
                                    <ul>
                                        <li>4 Star</li>
                                        <li>
                                            <div class="progress">
                                                <div class="progress-bar bg-success" role="progressbar"
                                                    aria-label="4 start" style="width: 40%;" aria-valuenow="25"
                                                    aria-valuemin="0" aria-valuemax="100"></div>
                                            </div>
                                        </li>
                                        <li>({{ $four_star->count() }})</li>
                                    </ul>
                                    <!--review line-->
                                    <ul>
                                        <li>3 Star</li>
                                        <li>
                                            <div class="progress">
                                                <div class="progress-bar bg-success" role="progressbar"
                                                    aria-label="4 start" style="width: 20%;" aria-valuenow="25"
                                                    aria-valuemin="0" aria-valuemax="100"></div>
                                            </div>
                                        </li>
                                        <li>({{ $three_star->count() }})</li>
                                    </ul>
                                    <!--review line-->
                                    <ul>
                                        <li>2 Star</li>
                                        <li>
                                            <div class="progress">
                                                <div class="progress-bar bg-warning" role="progressbar"
                                                    aria-label="4 start" style="width: 10%;" aria-valuenow="25"
                                                    aria-valuemin="0" aria-valuemax="100"></div>
                                            </div>
                                        </li>
                                        <li>({{ $two_star->count() }})</li>
                                    </ul>
                                    <!--review line-->
                                    <ul>
                                        <li>1 Star</li>
                                        <li>
                                            <div class="progress">
                                                <div class="progress-bar bg-danger" role="progressbar"
                                                    aria-label="4 start" style="width: 1%;" aria-valuenow="25"
                                                    aria-valuemin="0" aria-valuemax="100"></div>
                                            </div>
                                        </li>
                                        <li>({{ $one_star->count() }})</li>
                                    </ul>
                                    <!--review line-->
                                </div>
                                <!-- review line end -->
                            </div>
                        </div>
                        <div class="customer-review">
                            <div class="row">
                                @foreach ($reviews as $key => $review)
                                    <div class="col-sm-12 col-12">
                                        <div class="review-card">
                                            <p class="reviewer_name"><i data-feather="message-square"></i>
                                                {{ $review->name }}</p>
                                            <p class="review_data">{{ $review->created_at }}</p>
                                            <p class="review_star">{!! str_repeat('<i class="fa-solid fa-star"></i>', $review->ratting) !!}</p>
                                            <p class="review_content">{{ $review->review }}</p>
                                        </div>
                                    </div>
                                @endforeach
                            </div>
                        </div>
                    @else
                        <div class="empty-content">
                            <i class="fa fa-clipboard-list"></i>
                            <p class="empty-text">This product has no reviews yet. Be the first one to write a review.</p>
                        </div>
                        @endif
                        <div class="modal fade" id="exampleModal" tabindex="-1" aria-labelledby="exampleModalLabel"
                            aria-hidden="true">
                            <div class="modal-dialog">
                                <div class="modal-content">
                                    <div class="modal-header">
                                        <h1 class="modal-title fs-5" id="exampleModalLabel">Your review</h1>
                                        <button type="button" class="btn-close" data-bs-dismiss="modal"
                                            aria-label="Close"></button>
                                    </div>
                                    <div class="modal-body">
                                        <div class="insert-review">
                                            @if (Auth::guard('customer')->user())
                                                <form action="{{ route('customer.review') }}" id="review-form"
                                                    method="POST">
                                                    @csrf
                                                    <input type="hidden" name="product_id" value="{{ $details->id }}">
                                                    <div class="fz-12 mb-2">
                                                        <div class="rating">
                                                            <label title="Excelent">
                                                                ☆
                                                                <input required type="radio" name="ratting"
                                                                    value="5" />
                                                            </label>
                                                            <label title="Best">
                                                                ☆
                                                                <input required type="radio" name="ratting"
                                                                    value="4" />
                                                            </label>
                                                            <label title="Better">
                                                                ☆
                                                                <input required type="radio" name="ratting"
                                                                    value="3" />
                                                            </label>
                                                            <label title="Very Good">
                                                                ☆
                                                                <input required type="radio" name="ratting"
                                                                    value="2" />
                                                            </label>
                                                            <label title="Good">
                                                                ☆
                                                                <input required type="radio" name="ratting"
                                                                    value="1" />
                                                            </label>
                                                        </div>
                                                    </div>

                                                    <div class="form-group">
                                                        <label for="message-text" class="col-form-label">Message:</label>
                                                        <textarea required class="form-control radius-lg" name="review" id="message-text"></textarea>
                                                        <span id="validation-message" style="color: red;"></span>
                                                    </div>
                                                    <div class="form-group">
                                                        <button class="details-review-button" type="submit">Submit
                                                            Review</button>
                                                    </div>

                                                </form>
                                            @else
                                                <a class="customer-login-redirect"
                                                    href="{{ route('customer.login') }}">Login
                                                    to Post
                                                    Your Review</a>
                                            @endif
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        </div>
        <div class="col-sm-4">
            <div class="pro_vide">
                <h2>Video</h2>
                <iframe width="100%" height="315" src="https://www.youtube.com/embed/{{ $details->pro_video }}"
                    title="YouTube video player" frameborder="0"
                    allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share"
                    allowfullscreen></iframe>
            </div>
        </div>
        </div>
        </div>
    </section>

    <section class="related-product-section">
        <div class="container">
            <div class="row">
                <div class="related-title">
                    <h5>Related Product</h5>
                </div>
            </div>
            <div class="row">
                <div class="col-sm-12">
                    <div class="product-inner owl-carousel related_slider">
                        @foreach ($products as $key => $value)
                            <div class="product_item wist_item wow fadeInDown" data-wow-duration="1.5s"
                                data-wow-delay="0.{{ $key }}s">
                                <div class="product_item_inner">
                                    @if ($value->old_price)
                                        <div class="sale-badge">
                                            <div class="sale-badge-inner">
                                                <div class="sale-badge-box">
                                                    <span class="sale-badge-text">
                                                        <p>@php
                                                            $discount =
                                                                (($value->old_price - $value->new_price) * 100) /
                                                                $value->old_price;
                                                        @endphp
                                                            {{ number_format($discount, 0) }}% OFF</p>

                                                    </span>
                                                </div>
                                            </div>
                                        </div>
                                    @endif
                                    <div class="pro_img">
                                        <a href="{{ route('product', $value->slug) }}">
                                            <img src="{{ asset($value->image ? $value->image->image : '') }}"
                                                alt="{{ $value->name }}" />
                                        </a>
                                    </div>
                                    <div class="pro_des">
                                        <div class="pro_name">
                                            <a
                                                href="{{ route('product', $value->slug) }}">{{ Str::limit($value->name, 40) }}</a>
                                        </div>
                                        <div class="product_unit">
                                            <p>{{ $value->pro_unit }}</p>
                                        </div>
                                        <div class="pro_price">
                                            <p>
                                                ৳ {{ number_format($value->new_price, 0) }}
                                            </p>
                                            @if ($value->old_price)
                                                <p>
                                                    <del>৳ {{ number_format($value->old_price, 0) }}</del>
                                                </p>
                                            @endif
                                        </div>
                                        @if (($value->variables_count < 1 && $value->type == 1) || ($value->quantity < 1 && $value->type == 0))
                                            <div class="Out_stock_btn">
                                                <li><a>Sold Out</a></li>
                                            </div>
                                        @else
                                            <div class="pro__btn">
                                                @if ($value->variables_count < 1)
                                                    <button data-id="{{ $value->id }}" class="add_to_cart">Add to
                                                        cart</button>
                                                @else
                                                    <a href="{{ route('product', $value->slug) }}" class="add_to_cart">Add
                                                        to cart</a>
                                                @endif
                                                <a class="view_deatils_btn"
                                                    href="{{ route('product', $value->slug) }}">View details</a>
                                            </div>
                                        @endif
                                    </div>
                                </div>

                            </div>
                        @endforeach
                    </div>
                </div>
            </div>
        </div>
    </section>

    @endsection @push('script')
    <script src="{{ asset('public/frontEnd/js/owl.carousel.min.js') }}"></script>

    <script src="{{ asset('public/frontEnd/js/zoomsl.min.js') }}"></script>

    <script>
        $(document).ready(function() {
            $(".details_slider").owlCarousel({
                margin: 15,
                items: 1,
                loop: true,
                dots: false,
                autoplay: true,
                autoplayTimeout: 6000,
                autoplayHoverPause: true,
            });
            $(".indicator-item").on("click", function() {
                var slideIndex = $(this).data("id");
                $(".details_slider").trigger("to.owl.carousel", slideIndex);
            });
        });
    </script>
    <!--Data Layer Start-->
    <script type="text/javascript">
        window.dataLayer = window.dataLayer || [];
        dataLayer.push({
            ecommerce: null
        });
        dataLayer.push({
            event: "view_item",
            ecommerce: {
                items: [{
                    item_name: "{{ $details->name }}",
                    item_id: "{{ $details->id }}",
                    price: "{{ $details->new_price }}",
                    item_brand: "{{ $details->brand ? $details->brand->name : '' }}",
                    item_category: "{{ $details->category->name }}",
                    item_variant: "{{ $details->pro_unit }}",
                    currency: "BDT",
                    quantity: {{ $details->stock ?? 0 }}
                }],
                impression: [
                    @foreach ($products as $value)
                        {
                            item_name: "{{ $value->name }}",
                            item_id: "{{ $value->id }}",
                            price: "{{ $value->new_price }}",
                            item_brand: "{{ $details->brand ? $details->brand->name : '' }}",
                            item_category: "{{ $value->category ? $value->category->name : '' }}",
                            item_variant: "{{ $value->pro_unit }}",
                            currency: "BDT",
                            quantity: {{ $value->stock ?? 0 }}
                        },
                    @endforeach
                ]
            }
        });
    </script>
    <script type="text/javascript">
        $(document).ready(function() {
            $('#add_to_cart').click(function() {
                gtag("event", "add_to_cart", {
                    currency: "BDT",
                    value: "1.5",
                    items: [
                        @foreach (Cart::instance('shopping')->content() as $cartInfo)
                            {
                                item_id: "{{ $details->id }}",
                                item_name: "{{ $details->name }}",
                                price: "{{ $details->new_price }}",
                                currency: "BDT",
                                quantity: {{ $cartInfo->qty ?? 0 }}
                            },
                        @endforeach
                    ]
                });
            });
        });
    </script>
    <script type="text/javascript">
        $(document).ready(function() {
            $('#order_now').click(function() {
                gtag("event", "add_to_cart", {
                    currency: "BDT",
                    value: "1.5",
                    items: [
                        @foreach (Cart::instance('shopping')->content() as $cartInfo)
                            {
                                item_id: "{{ $details->id }}",
                                item_name: "{{ $details->name }}",
                                price: "{{ $details->new_price }}",
                                currency: "BDT",
                                quantity: {{ $cartInfo->qty ?? 0 }}
                            },
                        @endforeach
                    ]
                });
            });
        });
    </script>

    <!-- Data Layer End-->
    <script>
        $(document).ready(function() {
            $(".related_slider").owlCarousel({
                margin: 10,
                items: 6,
                loop: true,
                dots: false,
                nav: false,
                autoplay: true,
                autoplayTimeout: 6000,
                autoplayHoverPause: true,
                responsiveClass: true,
                responsive: {
                    0: {
                        items: 2,
                    },
                    600: {
                        items: 3,
                        nav: false,
                    },
                    1000: {
                        items: 6,
                        loop: true,
                    },
                },
            });
            // $('.owl-nav').remove();
        });
    </script>
    <script>
        $(document).ready(function() {
            $(".minus").click(function() {
                var $input = $(this).parent().find("input");
                var count = parseInt($input.val()) - 1;
                count = count < 1 ? 1 : count;
                $input.val(count);
                $input.change();
                return false;
            });
            $(".plus").click(function() {
                var maxValue = $('.stock_summary p').data('stock');
                console.log('stock', maxValue);
                var $input = $(this).parent().find("input");
                var currentValue = parseInt($input.val());
                if (currentValue < maxValue) {
                    $input.val(currentValue + 1);
                    $input.change();
                } else {
                    toastr.error('failed', 'Product limit is over');
                }
                return false;
            });
        });
    </script>

    <script>
        function sendSuccess() {
            // size validation
            size = document.forms["formName"]["product_size"].value;
            if (size != "") {
                // access
            } else {
                toastr.warning("Please select any size");
                return false;
            }
            color = document.forms["formName"]["product_color"].value;
            if (color != "") {
                // access
            } else {
                toastr.error("Please select any color");
                return false;
            }
        }
    </script>
    <script>
        $(document).ready(function() {
            $(".rating label").click(function() {
                $(".rating label").removeClass("active");
                $(this).addClass("active");
            });
        });
    </script>
    <script>
        $(".stock_check").on("click", function() {
            var color = $(".stock_color:checked").data('color');
            var size = $(".stock_size:checked").data('size');
            var id = {{ $details->id }};
            if (id, color, size) {
                $.ajax({
                    type: "GET",
                    data: {
                        id: id,
                        color: color,
                        size: size
                    },
                    url: "{{ route('stock_check') }}",
                    dataType: "html",
                    success: function(response) {
                        $('.stock_summary').html('<p data-stock="' + response + '"><strong>Stock: ' +
                            response + '</strong></p>');
                    }
                });
            }

        });
    </script>
    <script>
        $(document).ready(function() {
            $(".thumb_slider").owlCarousel({
                margin: 15,
                items: 4,
                loop: true,
                dots: false,
                nav: true,
                autoplayTimeout: 6000,
                autoplayHoverPause: true,
            });
        });
    </script>

    <script type="text/javascript">
        $(".block__pic").imagezoomsl({
            zoomrange: [3, 3]
        });
    </script>
@endpush
